function [t,y] = getyplot(dglname,options,knoten,ya,u,nzk,parameter)
% ---------------------------------------------------------------
% Loesung eines Optimalsteuerungsproblems
%
% In diesem File wird die Trajektorie intervallweise integeriert.
% Die Trajektorie wird an nzk+1 Stellen in [knoten(j),knoten(j+1)] bestimmt.
% Dies ist fuer nzk>1 zum Zeichnen der Trajektorie nuetzlich. 
% Dieses File ist nicht an ein spezielles Beispiel gebunden!
% ---------------------------------------------------------------
% Eingabe - Parameter
% dglname : Name der Datei, in denen die Differentialgleichungen definiert sind.
% options : Optionen fuer den DGL-Loeser, die mit odeset gesetzt werden koennen.
% knoten: Die einzelnen Diskretisierungspunkte
% ya : (ndgl)-Vektor der Anfangswerte
% u  : (n+1)-Vektor. u_i Steuerung fuer das Intervall [t_i,t_{i+1}]
% nzk: Anzahl der Zwischenknoten im Intervall [knoten_j, knoten_{j+1}[
% parameter : enthaelt Parameter, die unveraendert an das odefile 
%             weitergegeben werden.
% ---------------------------------------------------------------
% Rueckgabe - Parameter:
% t : (n*nzk+1) Vektor der Argumente zu y.
% y : (n*nzk+1) x ndgl Matrix. y_{j k} gibt den Zustand y_k(t_j) an.
% ---------------------------------------------------------------

ndgl = size(ya,1);
n = size(knoten,1)-1;
t = [];
y = [];

for j=1:n
   % das j-te Intervall wird definiert.
   tspan = [knoten(j):(knoten(j+1)-knoten(j))/nzk:knoten(j+1)];
   % der Wert von y(t_{j+1}) wird bestimmt
   [tj1,yj1] = ode45(dglname,tspan,ya,options,u(j),parameter);
   y = cat(1,y,yj1);
   t = cat(1,t,tj1);
   ya = yj1(nzk+1,:)';
end;
